summaryrefslogtreecommitdiffstats
path: root/kalzium/src/detailinfodlg.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 21:03:50 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 21:03:50 -0600
commit741251f28014550865f29798c46bec4cb079d578 (patch)
tree169846c81334553c44e9cbba7169b9ad4d0ae89b /kalzium/src/detailinfodlg.h
parentfec3b97db2e3c0296bb1beee021df8f47b72b154 (diff)
downloadtdeedu-741251f28014550865f29798c46bec4cb079d578.tar.gz
tdeedu-741251f28014550865f29798c46bec4cb079d578.zip
Rename kiobuffer and KHTML
Diffstat (limited to 'kalzium/src/detailinfodlg.h')
-rw-r--r--kalzium/src/detailinfodlg.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kalzium/src/detailinfodlg.h b/kalzium/src/detailinfodlg.h
index ba853bf5..d2027f8b 100644
--- a/kalzium/src/detailinfodlg.h
+++ b/kalzium/src/detailinfodlg.h
@@ -30,7 +30,7 @@ class TQFrame;
class TQLabel;
class TQVBoxLayout;
class KActionCollection;
-class KHTMLPart;
+class TDEHTMLPart;
/**
* @short The dialog which shows all available information of an element
@@ -63,7 +63,7 @@ class DetailedInfoDlg : public KDialogBase
TQString isotopeTable();
- TQMap<TQString, KHTMLPart*> m_htmlpages;
+ TQMap<TQString, TDEHTMLPart*> m_htmlpages;
TQLabel *piclabel;
@@ -93,17 +93,17 @@ class DetailedInfoDlg : public KDialogBase
* @param icontext The name of the tab, appears belov or instead
* of the icon
* @param iconname The name of the icon
* @returns the pointer to the resulting KHTMLPart, needed for
* writing HTML code on it
*/
- KHTMLPart* addHTMLTab( const TQString& title, const TQString& icontext, const TQString& iconname );
+ TDEHTMLPart* addHTMLTab( const TQString& title, const TQString& icontext, const TQString& iconname );
/**
* Change the HTML code in an HTML page.
*
* @param htmlpart the KHTMLPart to edit
* @param htmlcode the HTML code to display
*/
- void fillHTMLTab( KHTMLPart* htmlpart, const TQString& htmlcode );
+ void fillHTMLTab( TDEHTMLPart* htmlpart, const TQString& htmlcode );
protected slots:
virtual void slotUser1();
@@ -93,17 +93,17 @@ class DetailedInfoDlg : public KDialogBase
* of the icon
* @param iconname The name of the icon
- * @returns the pointer to the resulting KHTMLPart, needed for
+ * @returns the pointer to the resulting TDEHTMLPart, needed for
* writing HTML code on it
*/
@@ -93,17 +93,17 @@ class DetailedInfoDlg : public KDialogBase
* Change the HTML code in an HTML page.
*
- * @param htmlpart the KHTMLPart to edit
+ * @param htmlpart the TDEHTMLPart to edit
* @param htmlcode the HTML code to display
*/